@@ -4,7 +4,7 @@
 import importlib
 import os
 import copy
-from  flagai.model.file_utils import _get_model_id
+from flagai.model.file_utils import _get_model_id
 
 
 class LazyImport(object):
@@ -28,18 +28,18 @@ ALL_TASK = {
     "bert_title-generation": ["flagai.model.bert_model", "BertForSeq2seq"],
     "bert_masklm": ["flagai.model.bert_model", "BertForMaskLM"],
     "bert_sequence-labeling":
-    ["flagai.model.bert_model", "BertForSequenceLabeling"],
+        ["flagai.model.bert_model", "BertForSequenceLabeling"],
     "bert_sequence-labeling-crf":
-    ["flagai.model.bert_model", "BertForSequenceLabeling"],
+        ["flagai.model.bert_model", "BertForSequenceLabeling"],
     "bert_sequence-labeling-gp":
-    ["flagai.model.bert_model", "BertForSequenceLabeling"],
+        ["flagai.model.bert_model", "BertForSequenceLabeling"],
     "bert_ner": ["flagai.model.bert_model", "BertForSequenceLabeling"],
     "bert_ner-crf": ["flagai.model.bert_model", "BertForSequenceLabelingCRF"],
     "bert_ner-gp": ["flagai.model.bert_model", "BertForSequenceLabelingGP"],
     "bert_embedding": ["flagai.model.bert_model", "BertForEmbedding"],
     "bert_classification": ["flagai.model.bert_model", "BertForClsClassifier"],
     "bert_semantic-matching":
-    ["flagai.model.bert_model", "BertForClsClassifier"],
+        ["flagai.model.bert_model", "BertForClsClassifier"],
     "gpt2_seq2seq": ("flagai.model.gpt2_model", "GPT2Model"),
     "gpt2_lm": ("flagai.model.gpt2_model", "GPT2Model"),
     "cpm_seq2seq": ("flagai.model.gpt2_model", "GPT2Model"),
@@ -50,7 +50,7 @@ ALL_TASK = {
     "glm_seq2seq": ["flagai.model.glm_model", "GLMForSeq2Seq"],
     "glm_poetry": ["flagai.model.glm_model", "GLMForSeq2Seq"],
     "glm_classification":
-    ["flagai.model.glm_model", "GLMForSequenceClassification"],
+        ["flagai.model.glm_model", "GLMForSequenceClassification"],
     "glm_title-generation": ["flagai.model.glm_model", "GLMForSeq2Seq"],
     "opt_seq2seq": ("flagai.model.opt_model", "OPTModel"),
     "opt_lm": ("flagai.model.opt_model", "OPTModel"),
@@ -73,6 +73,7 @@ MODEL_DICT = {
     "t5-base-en": ["flagai.model.t5_model", "T5Model", "t5", "nlp"],
     "t5-base-ch": ["flagai.model.t5_model", "T5Model", "t5", "nlp"],
     "glm-large-ch": ["flagai.model.glm_model", "GLMModel", "glm", "nlp"],
+    "alm-1.0": ["flagai.model.glm_model", "GLMModel", "glm", "nlp"],
     "glm-large-en": ["flagai.model.glm_model", "GLMModel", "glm", "nlp"],
     "gpt2-base-ch": ["flagai.model.gpt2_model", "GPT2Model", "gpt2", "nlp"],
     "cpm-large-ch": ["flagai.model.gpt2_model", "GPT2Model", "cpm", "nlp"],
@@ -88,21 +89,21 @@ MODEL_DICT = {
     "cpm3": ["flagai.model.cpm3_model", "CPM3", "cpm3", "nlp"],
     "cpm3-train": ["flagai.model.cpm3_train_model", "CPM3", "cpm3", "nlp"],
     "vit-base-p16-224":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-base-p16-384":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-base-p32-224":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-base-p32-384":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-large-p16-224":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-large-p16-384":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-large-p32-224":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "vit-large-p32-384":
-    ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
+        ["flagai.model.vision.vit", "VisionTransformer", "vit", "vision"],
     "clip-base-p32-224": ["flagai.model.mm.clip_model", "CLIP", "clip", "mm"],
     "clip-base-p16-224": ["flagai.model.mm.clip_model", "CLIP", "clip", "mm"],
     "clip-large-p14-224": ["flagai.model.mm.clip_model", "CLIP", "clip", "mm"],
@@ -113,20 +114,24 @@ MODEL_DICT = {
     "altdiffusion-m9":
     ["flagai.model.mm.diffusion", "LatentDiffusion", "diffusion", "mm","flagai.model.mm.AltCLIP", "AltCLIPProcess"],
     "swinv1-base-patch4-window7-224":
-    ["flagai.model.vision.swinv1", "SwinTransformer", "swinv1", "vision"],
+        ["flagai.model.vision.swinv1", "SwinTransformer", "swinv1", "vision"],
     "swinv2-base-patch4-window8-256":
-    ["flagai.model.vision.swinv2", "SwinTransformerV2", "swinv2", "vision"],
+        ["flagai.model.vision.swinv2", "SwinTransformerV2", "swinv2", "vision"],
     "swinv2-base-patch4-window16-256":
-    ["flagai.model.vision.swinv2", "SwinTransformerV2", "swinv2", "vision"],
+        ["flagai.model.vision.swinv2", "SwinTransformerV2", "swinv2", "vision"],
     "swinv2-small-patch4-window16-256": [
         "flagai.model.vision.swinv2", "SwinTransformerV2", "swinv2", "vision"
     ],
-    "altclip-xlmr-l": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP", "AltCLIPProcess"],
-    "altclip-xlmr-l-m9": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP", "AltCLIPProcess"],
-    "altclip-bert-b": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP", "AltCLIPProcessBert"],
+    "altclip-xlmr-l": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP",
+                       "AltCLIPProcess"],
+    "altclip-xlmr-l-m9": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP",
+                          "AltCLIPProcess"],
+    "altclip-bert-b": ["flagai.models.mm.AltCLIP", "AltCLIP", "altclip", "mm", "flagai.model.mm.AltCLIP",
+                       "AltCLIPProcessBert"],
     "eva-clip": ["flagai.model.mm.eva_clip_model", "EVA_CLIP", "evaclip", "mm"],
 }
 
+
 class AutoLoader:
 
     def __init__(self,
@@ -198,11 +203,11 @@ class AutoLoader:
 
         self.model = getattr(LazyImport(self.model_name[0]),
                              self.model_name[1]).from_pretrain(
-                                 download_path=model_dir,
-                                 model_name=model_name_,
-                                 only_download_config=only_download_config,
-                                 device=device,
-                                 **kwargs)
+            download_path=model_dir,
+            model_name=model_name_,
+            only_download_config=only_download_config,
+            device=device,
+            **kwargs)
 
         if model_type == "nlp":
             tokenizer_class = getattr(LazyImport("flagai.data.tokenizer"),
@@ -222,15 +227,15 @@ class AutoLoader:
                 self.transform = None
             else:
                 self.process = getattr(LazyImport(MODEL_DICT[model_name][4]),
-                                MODEL_DICT[model_name][5]).from_pretrained(os.path.join(model_dir, raw_model_name))
+                                       MODEL_DICT[model_name][5]).from_pretrained(
+                    os.path.join(model_dir, raw_model_name))
                 self.transform = self.process.feature_extractor
                 self.tokenizer = self.process.tokenizer
 
-        else :
+        else:
             self.tokenizer = None
             self.transform = None
 
-
     def get_task_name(self, brief_model_name):
         all_model_task = list(ALL_TASK.keys())
         model_tasks = [t for t in all_model_task if brief_model_name in t]
@@ -243,7 +248,7 @@ class AutoLoader:
 
     def get_model(self):
         return self.model
-    
+
     def get_transform(self):
         return self.transform
 
