@@ -53,7 +53,7 @@ DEFAULT_COMMAND_TOKENS = [
     ('unk', 3),
     ('sep', 4),
     ('L2R', 5),
-    ('ENC', 6),
+    ('cls', 6),
     ('MASK', 7),
 ]
 DEFAULT_COMMAND_TOKENS = prep_command_tokens(DEFAULT_COMMAND_TOKENS)
@@ -96,6 +96,9 @@ DEFAULT_TYPE_TOKENS = [
 DEFAULT_TYPE_TOKENS = prep_type_tokens(DEFAULT_TYPE_TOKENS)
 
 
+
+
+
 class GLMTokenizer(object):
     """
     Tokenizer object that handles text tokenization, command tokens, and type tokens.
@@ -170,7 +173,7 @@ class GLMTokenizer(object):
         """total number of tokens"""
         return self.num_tokens
 
-    def get_command(self, name):
+    def get_command_id(self, name):
         """get command token corresponding to `name`"""
         return self.command_name_map[name]
 
@@ -284,9 +287,6 @@ class GLMTokenizer(object):
         no_split_tokens = self._command_tokens
         Ids = split_on_tokens(no_split_tokens, processed_text)
         return Ids
-        # tokenization = Tokenization(Ids, processed_text, text)
-        # tokenization.set_command_tokens(self._command_tokens)
-        # return tokenization
 
     def _encode(self, text):
         raise NotImplementedError
@@ -370,6 +370,8 @@ class GLMTokenizer(object):
         return ' '.join(rtn_strs)
 
 
+
+
 class Tokenizer(object):
     """
     Tokenizer object that handles text tokenization, command tokens, and type tokens.
@@ -456,6 +458,8 @@ class Tokenizer(object):
         return self.text_tokenizer.convert_tokens_to_string(tokens)
 
 
+# class BaseTokenizer(object):
+
 class TextTokenizer(object):
     """
     Interface for text tokenizer
