@@ -131,6 +131,7 @@ class BertModel(BaseModel):
 
         self.apply(init_bert_weights)
 
+
     def forward(self,
                 input_ids,
                 token_type_ids=None,
@@ -150,9 +151,25 @@ class BertModel(BaseModel):
         # this attention mask is more simple than the triangular masking of causal attention
         # used in OpenAI GPT, we just need to prepare the broadcast dimension here.
         if attention_mask is not None:
+            input_attention_mask_dim = len(attention_mask.shape)
+            if input_attention_mask_dim == 4:
+                # seq2seq mask
+                extended_attention_mask = extended_attention_mask.unsqueeze(1).unsqueeze(2)
+            elif input_attention_mask_dim == 3:
+                extended_attention_mask = extended_attention_mask.unsqueeze(1)
+            elif input_attention_mask_dim == 2:
+                # not need to extend
+                pass
             extended_attention_mask = extended_attention_mask * attention_mask
-        extended_attention_mask = extended_attention_mask.unsqueeze(
-            1).unsqueeze(2)
+
+        # extended_attention_mask need to extend to 4 dimentions.
+        extended_attention_mask_dim = len(extended_attention_mask.shape)
+        if extended_attention_mask_dim == 2:
+            extended_attention_mask = extended_attention_mask.unsqueeze(1).unsqueeze(2)
+        elif extended_attention_mask_dim == 3:
+            extended_attention_mask = extended_attention_mask.unsqueeze(1)
+        elif extended_attention_mask_dim == 4:
+            pass
         # Since attention_mask is 1.0 for positions we want to attend and 0.0 for
         # masked positions, this operation will create a tensor which is 0.0 for
         # positions we want to attend and -10000.0 for masked positions.
@@ -356,7 +373,6 @@ class BertForSeq2seq(BaseModel):
         input_shape = input_ids.shape
         seq_len = input_shape[1]
         a_mask = self.make_unilm_mask(token_type_ids, seq_len)
-
         encoder_out, pooler_out = self.model(
             input_ids,
             token_type_ids,
