@@ -70,3 +70,16 @@ def normal_init_method(mean=0.0, std=0.02):
         return torch.nn.init.normal_(tensor, mean=mean, std=std)
 
     return init_
+    
+from itertools import repeat
+import collections.abc
+# From PyTorch internals
+def _ntuple(n):
+    def parse(x):
+        if isinstance(x, collections.abc.Iterable):
+            return x
+        return tuple(repeat(x, n))
+    return parse
+
+
+to_2tuple = _ntuple(2) #for clip 
\ No newline at end of file
